Welcome to Prapti.

It's early, and we're just getting started.

### Current Status, July 22, 2023

In the unlikely event that you're interested in contributing to this repo, here is the current status:

- We're in the process of making the codebase technically robust (i.e., strengthening the foundation, stabilizing the API, getting to full test coverage).
- We anticipate that you'll be able to implement most of your ideas as plugins external to our repository.
- We have a placeholder for plugins, but the API is not stable yet. If you'd like to make a plugin, please feel free to reach out to discuss improvements needed for your use-case.

We're open to discussing our development direction if you'd like to get involved.

### Contributing

To make direct contributions, please use the following areas on our GitHub repo:

- *Issues* for bug reports
- *Pull Requests* for code contributions
- *Discussions* for general queries and suggestions

As for as what we'll accept, for now:

- We're definitely interested in bug reports and bug fixes.
- For anything beyond typos and one-line fixes, please post a bug report as an issue prior to submitting any PR that fixes the issue.
- For new features to the core, please open a discussion prior to creating an issue or PR.

Prapti is open source. Feel free to fork our repo and do your own thing. If it's something you'd like to share, we would love you to post it in our discussions area.

Thank you!

Ross and Scott
